multiclass-metrics documentation table of contents
======================================

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   Overview <index>
   API <multiclass_metrics>
   changelog
